@@ -17,7 +17,6 @@ import uuid
 import warnings
 
 from datetime import datetime
-from pprint import pformat
 from types import FunctionType
 
 if sys.version_info >= (3, 2):
@@ -138,7 +137,7 @@ class Client(object):
 
     def __init__(self, dsn=None, raise_send_errors=False, transport=None,
                  install_sys_hook=True, install_logging_hook=True,
-                 hook_libraries=None, **options):
+                 hook_libraries=None, enable_breadcrumbs=True, **options):
         global Raven
 
         o = options
@@ -194,6 +193,7 @@ class Client(object):
         # We want to remember the creating thread id here because this
         # comes in useful for the context special handling
         self.main_thread_id = get_thread_ident()
+        self.enable_breadcrumbs = enable_breadcrumbs
 
         from raven.context import Context
         self._context = Context(self)
@@ -460,13 +460,14 @@ class Client(object):
         data.setdefault('sdk', SDK_VALUE)
 
         # insert breadcrumbs
-        crumbs = self.context.breadcrumbs.get_buffer()
-        if crumbs:
-            # Make sure we send the crumbs here as "values" as we use the
-            # raven client internally in sentry and the alternative
-            # submission option of a list here is not supported by the
-            # internal sender.
-            data.setdefault('breadcrumbs', {'values': crumbs})
+        if self.enable_breadcrumbs:
+            crumbs = self.context.breadcrumbs.get_buffer()
+            if crumbs:
+                # Make sure we send the crumbs here as "values" as we use the
+                # raven client internally in sentry and the alternative
+                # submission option of a list here is not supported by the
+                # internal sender.
+                data.setdefault('breadcrumbs', {'values': crumbs})
 
         return data
 
@@ -626,9 +627,10 @@ class Client(object):
                 type(exc).__name__, exc.message)
         else:
             self.error_logger.error(
-                'Sentry responded with an error: %s (url: %s)\n%s',
-                exc, url, pformat(data),
-                exc_info=True
+                'Sentry responded with an error: %s (url: %s)',
+                exc, url,
+                exc_info=True,
+                extra={'data': data}
             )
 
         self._log_failed_submission(data)
@@ -829,14 +831,14 @@ class Client(object):
             DeprecationWarning)
         return self.context(**kwargs)
 
-    def captureBreadcrumb(self, type, *args, **kwargs):
+    def captureBreadcrumb(self, *args, **kwargs):
         """Records a breadcrumb with the current context.  They will be
         sent with the next event.
         """
         # Note: framework integration should not call this method but
         # instead use the raven.breadcrumbs.record_breadcrumb function
         # which will record to the correct client automatically.
-        self.context.breadcrumbs.record(type, *args, **kwargs)
+        self.context.breadcrumbs.record(*args, **kwargs)
 
     capture_breadcrumb = captureBreadcrumb
 
